@@ -267,6 +267,20 @@ GgitRemote         *ggit_repository_create_remote     (GgitRepository        *re
                                                        const gchar           *url,
                                                        GError               **error);
 
+gboolean            ggit_repository_remove_remote     (GgitRepository        *repository,
+                                                       const gchar           *name,
+                                                       GError               **error);
+
+gboolean            ggit_repository_set_remote_url    (GgitRepository        *repository,
+                                                       const gchar           *remote,
+                                                       const gchar           *url,
+                                                       GError               **error);
+
+gchar             **ggit_repository_rename_remote     (GgitRepository        *repository,
+                                                       const gchar           *name,
+                                                       const gchar           *new_name,
+                                                       GError               **error);
+
 gchar             **ggit_repository_list_remotes      (GgitRepository        *repository,
                                                        GError               **error);
 
@@ -287,6 +301,10 @@ gboolean            ggit_repository_set_head          (GgitRepository        *re
                                                        const gchar           *ref_name,
                                                        GError               **error);
 
+gboolean            ggit_repository_set_head_detached (GgitRepository        *repository,
+                                                       GgitOId               *oid,
+                                                       GError               **error);
+
 GFile              *ggit_repository_discover          (GFile                 *location,
                                                        GError               **error);
 
@@ -493,7 +511,7 @@ gboolean            ggit_repository_path_is_ignored    (GgitRepository
 
 void                ggit_repository_merge              (GgitRepository          *repository,
                                                         GgitAnnotatedCommit    **their_heads,
-                                                        gsize                   *their_heads_length,
+                                                        gsize                    their_heads_length,
                                                         GgitMergeOptions        *merge_opts,
                                                         GgitCheckoutOptions     *checkout_opts,
                                                         GError                 **error);
